package implement

import (
	"code.fnuoos.com/EggPlanet/egg_models.git/src/dao"
	"code.fnuoos.com/EggPlanet/egg_models.git/src/model"
	zhios_order_relate_logx "code.fnuoos.com/EggPlanet/egg_models.git/utils/logx"
	"errors"
	"xorm.io/xorm"
)

func NewEggEnergyPriceDb(engine *xorm.Engine) dao.EggEnergyPriceDao {
	return &EggEnergyPriceDb{Db: engine}
}

type EggEnergyPriceDb struct {
	Db *xorm.Engine
}

func (e EggEnergyPriceDb) EggEnergyPriceList(startAt string, endAt string, hour string) ([]model.EggEnergyPrice, error) {
	if startAt == "" || endAt == "" {
		return nil, zhios_order_relate_logx.Error(errors.New("startAt or endAt can not be empty").Error())
	}

	var m []model.EggEnergyPrice
	err := e.Db.Where("date >= ?", startAt).And("date <= ?", endAt).And("hour = ?", hour).Find(&m)
	if err != nil {
		return nil, zhios_order_relate_logx.Error(err.Error())
	}
	return m, nil
}

func (e EggEnergyPriceDb) EggEnergyPriceGetLastOne() (*model.EggEnergyPrice, bool, error) {
	var m model.EggEnergyPrice
	exist, err := e.Db.Desc("id").Get(&m)
	if err != nil {
		return nil, false, zhios_order_relate_logx.Error(err.Error())
	}
	return &m, exist, nil
}

func (e EggEnergyPriceDb) EggEnergyPriceInsert(eggEnergyPrice *model.EggEnergyPrice) (int64, error) {
	_, err := e.Db.InsertOne(eggEnergyPrice)
	if err != nil {
		return 0, zhios_order_relate_logx.Error(err.Error())
	}
	return eggEnergyPrice.Id, nil
}

func (e EggEnergyPriceDb) EggEnergyPriceUpdate(eggEnergyPrice *model.EggEnergyPrice) (int64, error) {
	affected, err := e.Db.ID(eggEnergyPrice.Id).Cols("price").Update(eggEnergyPrice)
	if err != nil {
		return 0, zhios_order_relate_logx.Error(err.Error())
	}
	return affected, nil
}
