package implement

import (
	"code.fnuoos.com/EggPlanet/egg_models.git/src/dao"
	"code.fnuoos.com/EggPlanet/egg_models.git/src/model"
	zhios_order_relate_utils "code.fnuoos.com/EggPlanet/egg_models.git/utils"
	zhios_order_relate_logx "code.fnuoos.com/EggPlanet/egg_models.git/utils/logx"
	"fmt"
	"reflect"
	"xorm.io/xorm"
)

func NewUserDb(engine *xorm.Engine) dao.UserDao {
	return &UserDb{Db: engine}
}

type UserDb struct {
	Db *xorm.Engine
}

func (u UserDb) UserGetOneByParams(params map[string]interface{}) (*model.User, error) {
	var m model.User
	var query = fmt.Sprintf("%s = ?", params["key"])
	if has, err := u.Db.Where(query, params["value"]).Get(&m); err != nil || has == false {
		return nil, zhios_order_relate_logx.Error(err)
	}
	return &m, nil
}

func (u UserDb) UserFindByParams(params map[string]interface{}) ([]model.User, error) {
	var m []model.User
	if reflect.TypeOf(params["value"]).Kind() == reflect.Slice {
		//指定In查询
		if err := u.Db.In(zhios_order_relate_utils.AnyToString(params["key"]), params["value"]).Find(&m); err != nil {
			return nil, zhios_order_relate_logx.Warn(err)
		}
	} else {
		var query = fmt.Sprintf("%s =?", params["key"])
		err := u.Db.Where(query, params["value"]).Find(&m)
		if err != nil {
			return nil, zhios_order_relate_logx.Error(err)
		}
	}
	return m, nil
}

func (u UserDb) UserUpdateBySession(session *xorm.Session, id interface{}, user *model.User, forceColumns ...string) (int64, error) {
	var (
		affected int64
		err      error
	)
	if forceColumns != nil {
		affected, err = session.Where("id=?", id).MustCols(forceColumns...).Update(user)
	} else {
		affected, err = session.Where("id=?", id).Update(user)
	}
	if err != nil {
		return 0, err
	}
	return affected, nil
}

func (u UserDb) UserFindAndCount(uid int64, phone string, nickname string, level int, page, limit int) (*[]model.User, int64, error) {
	var m []model.User
	session := u.Db.NewSession()
	if uid != 0 {
		session = session.Where("uid=?", uid)
	}
	if phone != "" {
		session = session.Where("phone = ?", phone)
	}
	if nickname != "" {
		session = session.Where("nickname like ? ", "%"+nickname+"%")
	}
	if level != 0 {
		session = session.Where("level=?", level)
	}
	total, err := session.FindAndCount(&m)
	if err != nil {
		return nil, 0, zhios_order_relate_logx.Error(err)
	}
	return &m, total, nil
}
